from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x09\x00\x61\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x99\x08\x00\x00\x00\x00\x00\x18\x1e\x51\xc9\x36\x7d\x6d\x96\x96\xe4\xac\x79\x1f\xb8\xa9\x7b\x7b\x00\x00\x00\x00\x00\x00\x00\x00\x06\x46\x38\x1a\x28\x01\xa1\xed\x48\x14\xc7\xcb\x7f\x7c\x70\x61\xc7\x6f\xcb\x4b\x29\x06\xd5\xe1\xcd\x8f\x3e\x97\xbb\x06\x8a\xe7\x91\x08\x76\x70\x39\xdf\xb3\xb7\x1f\xc7\xca\xd4\x58\x72\x0f\x43\x7c\xe9\x07\x8a\x89\xa3\xf9\x20\x3f\x7f\x08\x32\x32\xc9\x0e\x47\x1c\x0d\x6e\x5d\x6f\x71\xb9\x52\x76\x7f\x79\x1f\x7f\x0d\xf1\x85\xf4\xdd\x4f\xba\xad\xcd\xdf\xea\xd3\x41\x11\xf3\x92\x39\x09\xb9\x6e\x2a\x9d\xed\x58\xec\xbf\xc9\xa6\x38\x5a\x15\x79\x1b\x5d\xbc\x9d\xe8\xc3\x7b\xb6\x5e\xfb\x89\x43\x52\x9e\xbf\x33\x05\x4b\xb0\x35\x9e\x4a\x86\xd7\xaa\x9f\x3e\xb2\x1b\x10\x63\x30\xfc\xc0\xcd\x1d\x89\x96\x0c\x2e\x47\x37\x4f\x0e\xfe\xd2\x54\x95\x40\xb4\x6f\xd3\xfc\x4f\x06\xaf\x1d\x38\x1a\xa2\xba\x27\x1d\x7a\xbf\x2f\x12\x33\x50\x41\xaf\x9e\x4a\x45\x69\xbf\xa0\x7d\x25\x5d\x1f\xe6\x71\x40\xe3\xfb\x58\x83\x0d\xba\x62\x6a\x77\x17\x4b\x69\x31\xc3\x89\xd0\xd8\x21\x1c\xdc\x1e\x3a\x47\x0a\xde\x98\xa9\x6a\xbb\xab\xad\x81\x59\xa8\x4f\xc6\x8f\xa9\x15\x13\x82\xfd\x1e\xa7\x91\xf1\xde\xf2\x8a\x4f\xe9\xc1\xea\x50\x3b\x18\xc1\xeb\xe0\x91\x25\xef\x39\x02\x08\x2d\xad\xa0\x8e\x79\xd1\x72\xae\x47\xba\xd8\x67\xf5\x2c\x54\x54\x3b\xda\x06\x8f\x95\xdb\xcd\x8b\x58\x2c\xb8\xf6\x5d\xff\x3d\x7f\x79\xce\x15\x92\x3d\x12\x64\xa3\x82\x7c\x47\x1f\xc8\x78\x4d\x7c\x66\xae\xbf\x79\x7d\x0e\x30\x8a\x1a\xfe\x17\xef\xd4\xd6\x2b\x27\x56\x8e\x3a\x31\x35\xb4\xff\x87\xe0\x3c\xcf\xea\xbd\x28\xb3\xf6\x97\xcb\x05\x4d\x43\x48\xac\x9d\x1d\x8c\x8c\x3c\x86\x7e\x35\x53\x26\xf7\xa6\x64\xb7\x5c\x78\x02\x89\xbc\xe8\x92\x6f\xb0\x8a\x63\xec\x3b\xcf\x63\x02\x38\x24\xb7\xfe\x48\x73\xc2\xaf\x60\x96\x28\x19\x65\x1d\x20\xf5\xf5\x33\x8c\x61\xce\x31\xb4\x91\xd0\x49\x4d\x78\xa9\x75\xe9\xc7\xe7\xfb\xf7\x7f\xaf\x85\xc6\x1a\x6b\xab\x11\x20\x96\xa8\x9b\x7e\xba\x21\xc8\x08\x77\xfa\xe9\xa5\xaa\x84\x29\x81\x9e\xba\xbd\x06\xd6\x4b\x37\xee\x3a\xc8\x26\x8d\xa7\x44\x5a\x33\x8a\x32\xa9\xe6\x3a\x71\x70\xeb\xfb\x98\x8e\xcb\x4c\xc7\xa4\x86\x7a\x03\xc7\xe6\x3a\x1f\x2f\x22\x08\x73\xbe\x1a\xf5\x17\x2a\xa0\x4f\x07\x12\x41\x00\x19\xa7\x6b\xfb\x8c\x67\xe3\x46\x3e\xe5\x02\x9c\x3e\xa2\x06\xc8\xfb\xcf\x5c\x8e\x89\x73\x5b\xb6\x46\xb0\x6c\xbd\xbf\x80\xc7\xe9\xf3\xd5\xdd\xed\x25\x8f\xa6\xe8\x36\x9f\x3b\xab\x3e\x39\x96\x12\xe7\x70\x98\x7d\x3d\x7d\x8e\x1b\x05\xfe\xac\x72\xcb\x3a\x07\x41\xca\x1d\xd7\x9a\x39\x3d\xd1\x26\x21\x28\x3a\xc1\x97\x17\xbf\x30\x34\x18\x79\xbc\xa2\x59\x2f\x84\xe8\xd5\xcb\x0c\xd3\x21\x0c\xb7\xe7\x9f\x9e\x19\x26\x21\xe4\xd2\x13\xa3\x5e\x8d\x21\x6f\x9f\x74\xc5\xda\x85\x04\x0c\xf9\xd5\x3d\xa3\xc6\xa0\xf0\x75\x25\x4d\x23\xa3\x47\x3f\xf8\xa8\x01\x62\x39\x34\xe1\xff\x86\x85\x7d\xbb\xe4\x8a\xc9\x3a\x4f\x1e\x9f\x4a\x11\x07\xcf\x2d\x7f\xc4\x1d\x97\x5f\x19\x9d\x07\x30\x40\xde\x5d\xf1\xb5\x83\x1f\x3c\x91\x28\xd5\x20\x8a\x4e\x12\xc5\x92\xf8\x85\x55\x00\x62\xd3\x0e\x9a\xa6\x91\x92\xe9\x4f\x4d\xc3\x34\xc3\x6e\x33\xd1\xa7\x3c\xc8\xa8\x44\x76\x8f\x66\x6b\x85\x7c\x75\x10\x19\x96\xef\x5b\x43\x41\x2c\xeb\x05\x3c\x54\x9e\x65\xe8\x90\xca\x59\x92\x22\x8b\x42\x3e\x62\x69\x9c\xec\x8c\xa4\xd4\x63\x9f\x44\x63\xe7\x7e\x9c\xd4\xde\x32\xa1\x95\x83\x0a\x2a\xe2\xc2\xdd\xaa\xdc\xbc\x42\xc3\x43\xb7\x24\xb1\x35\x56\x42\x16\x0d\x79\xec\x2c\x7b\xa7\x58\x7b\xab\x92\x33\xa9\x96\x27\x07\x4e\x86\x3b\xca\x2d\x4c\xa4\x1a\x09\x0c\x6a\x03\x35\xa6\xe6\x5f\x2a\xe5\x94\x55\x99\xce\x99\xb3\xf3\xc1\xd8\x8e\x2b\xdd\x74\xd1\x7e\xe0\x0d\x9a\x54\x71\x53\x92\xd6\x1d\xc9\x57\x22\xb0\x7c\x68\x30\x7f\x3c\xb0\xbb\xec\x37\x27\x1b\x61\xb5\x82\x78\xa2\x63\xaa\x6b\xa4\x3d\x73\xc3\xe9\x9d\x43\x42\x64\x6f\xa3\xcc\x1e\xe8\xc3\x8e\x6f\xd6\xeb\xdb\x03\x9c\xdb\x8b\x3a\x29\x0f\xeb\xf6\x0e\xac\x8d\xa7\x81\xba\x41\x00\xfa\x94\xe8\x6e\x16\x04\x7c\x4d\xbb\x16\xad\x75\x41\x62\xea\x27\x15\x9f\x1c\xbc\xc1\xbf\x3c\xa4\x35\xe4\xc5\x4e\x20\x99\x85\xd1\x78\x45\x8e\xe9\xa3\x48\xb1\xa9\x05\x48\xa8\x8e\xe6\x26\xb7\xe1\xb3\x3d\x6a\xac\x6b\xb5\xa2\xa1\x00\x3b\xe7\xe0\xee\x7e\x99\x65\xc2\xcc\x50\xfd\xc3\x9a\x8c\x79\x54\x4b\x34\xad\x79\x49\x90\x63\xa2\x5b\x21\xd0\x2c\xa5\x60\xf9\x0b\xb4\x10\xa1\xc0\xb2\xf1\x24\x1c\x51\x1e\x23\x19\x5a\x63\x0a\x94\x2d\xc7\x79\x99\xa2\x02\x10\x8e\xd9\xed\xd3\x7d\xca\x30\xd9\x74\x50\xb5\x35\x83\x78\x18\x20\x6e\x98\x9c\xe6\x6b\x4b\xb5\xdd\x6a\xa1\x12\x69\x9e\xb5\x58\x7d\xf1\xff\xe2\x2c\xed\xac\x37\xfc\x33\x6e\x39\x90\x58\x48\x8a\xa2\xc3\x11\x04\x6f\xd9\x80\xc4\xca\x12\x41\x5d\xcc\x55\x00\x3e\x58\x8a\x2d\x92\x8f\x6e\xe2\x51\x0a\x08\x95\x8c\x38\x95\x77\x4f\x24\x09\x12\x49\xe4\x86\x7f\x5e\x6e\x1b\x77\xc4\x7a\x00\xab\x10\x65\xd0\x15\x9e\xc9\xcc\x8e\x23\x93\xd7\x1e\xc6\xa6\x63\xbe\x3e\x14\x9d\x9f\x3f\x11\x5d\xf1\xf5\x30\x3c\xa3\xa1\xac\x76\x08\x40\x75\x8b\xd2\x8b\x8c\x70\x3f\x65\xba\x18\x62\xfd\xde\xd6\xcc\x86\x66\xbd\xc3\x50\x4a\x26\xa4\xef\x34\x42\xbd\xc1\x00\x96\x83\xb3\xc0\xae\x9f\x8d\xf7\x0d\xc1\x49\x81\x63\xac\xbc\xeb\xc8\xbf\x42\xa7\x84\x5c\xc8\xa1\x57\x9e\x0d\xde\xfe\x87\xf5\x13\x30\x37\x53\x5d\xea\x16\xc4\x45\xb9\x75\xb3\xd0\x66\x45\x4b\x60\x5f\xef\x12\x7b\x88\x40\x64\xf4\x85\xd9\xc3\xa4\x56\x90\xa6\xac\x02\xd4\x75\x74\xca\x83\x4c\x01\x99\x0a\x03\xa6\x84\xe9\x2b\xa1\x62\xda\x31\x76\xb5\xb0\xbe\x97\xaa\x2b\x13\xbf\x09\x7c\x03\x13\x0d\x69\x41\xd4\x42\xdc\x3b\xb4\x8f\xe3\x3f\xd2\x15\xe4\xb8\x57\xdd\x6b\x51\x0f\xa0\xdf\x28\x16\x96\x53\x04\x06\x8f\xcb\x45\x5b\xba\x29\xa1\x35\xe1\xd4\x6d\xe6\x24\xdd\x26\xef\xc5\xf3\x77\x91\x8e\x53\xbe\xb8\x24\x2d\x29\xf4\x12\xf4\xdf\x52\x3c\x00\x49\x26\x28\xe9\xa8\x05\xdb\xe4\x80\x7f\xb0\xe9\x9f\xb3\xba\x6e\xa8\x90\xd3\xa0\x3f\xf4\xc3\xd5\x64\x6c\x47\xfc\xbb\x67\xcf\xed\x9f\x2d\x24\x78\x77\xb2\x6e\xd2\xde\x13\xa4\x77\xa1\xf9\x5d\xa8\xa2\x90\xaa\x39\x64\xcf\x19\xb5\x44\x1e\x66\x6c\x0e\x35\x21\x08\x99\xcb\x05\x92\x6e\x6c\x71\x99\x16\x91\x31\x61\xe8\xab\x4c\xa6\xce\x20\xb3\x2f\x11\xcb\x75\x39\x9b\x42\xe0\x46\x90\xe9\x7c\x69\x97\x82\x34\xd7\x07\x30\x00\x5f\x50\x48\x8d\x3d\x9a\x54\x7b\x1c\xbf\x93\x15\xbb\x33\xd0\xc0\x90\xc0\xac\xf0\xc3\x1f\x99\xce\x97\x0b\x70\x62\x1d\x57\x38\xdc\x97\xea\x0f\x8f\xb7\xc5\x01\x0d\x20\xe8\xdc\x0d\x6e\x17\x8f\x24\x3a\x1a\x34\xe5\xe5\x4a\x05\xea\x15\x1c\x81\xd5\x62\x5b\xdb\x5e\x01\x31\x8c\xb2\x57\x40\x9d\x8e\x8a\x57\xfd\xd8\x3e\xfc\x54\x2c\x0c\x25\xae\x30\x34\x86\x3a\x23\x43\x43\x22\xcf\xa4\x8b\xd3\xd2\xd8\xea\x34\x32\x7e\x26\xca\xd1\x1b\x5d\x71\x46\x6e\xee\x3c\x1f\x82\xd6\x31\x37\xb0\x13\x45\x86\x1c\xa4\x96\x9d\xba\x05\x76\x24\x5a\x3b\x6a\x77\x0f\x6f\x7b\x13\x83\x11\x1e\x51\x2b\xfe\xcd\x97\x68\x96\x94\xf7\x00\xf1\x73\x56\x37\xa6\x19\x6a\xac\x5d\xa4\xf9\x46\x6e\x4f\x83\x95\xf0\x22\xf4\x35\x8c\x6c\x77\x7d\x2c\xf2\xd6\xc6\x51\x36\x3d\x8b\x44\xc3\xd5\x90\x82\x6d\x39\x3f\xf0\x3f\xd9\xd1\xed\x28\xec\x0c\x3e\x1b\xc8\x90\x6c\xb5\xd3\x17\xf0\xbb\x02\xfc\x72\x12\x1a\xa9\x9c\x1e\x65\x50\x92\xe2\x82\x20\x46\xdf\xbf\xd8\x7c\x33\x0e\x2b\x1a\x4c\x23\x62\x50\xdf\x48\x3e\x2a\xce\x60\x65\xdd\xd1\x1a\xe1\xf6\x23\xd0\xb0\xab\x05\x52\xd9\x2b\x54\x90\xca\xa9\x33\xfc\x49\xb0\xb3\xce\xee\x46\xab\xd1\xb2\x92\x0f\x22\x05\xf6\x37\x6e\x56\x96\x18\xdc\x59\x0d\xca\x95\xfc\x11\x70\xfb\x5d\xad\xd4\xc4\x79\x8c\x2a\xf5\xa1\xa2\xa0\xd5\x49\x60\x13\x87\xb3\xda\x17\x31\xa0\x08\xaf\xd7\xc1\xda\xe5\xd6\xff\x9c\x70\x61\x1f\xeb\xe0\x9b\x12\xc1\x13\x18\x33\x25\x03\xbc\xd4\xb4\xcf\xad\x96\xa4\xc9\x28\x42\xed\x44\x54\xe7\x53\x35\x84\xe2\x4e\xaf\xaf\x02\x82\x8e\x63\x9f\x11\x88\x40\x2b\x16\xb1\x4b\x61\x47\xec\x4b\x3f\xdd\x3a\x6a\x36\x58\x1c\x2e\xb1\x4e\x0a\xe3\x5e\x46\x34\x63\xf4\x4f\x85\x0a\xec\x0a\x71\x3c\x95\xf8\xca\x98\x37\x41\xe2\x4d\x93\xde\x42\x80\x59\x41\x28\x52\x1c\x01\x5d\x96\x9c\x47\x25\x69\x2a\x36\x35\xe4\xcd\xa5\x4b\x47\x8d\xdb\xd6\x53\x11\x1c\x3e\x9f\x90\x71\x03\x63\xa3\xd2\xc2\xdb\xef\xd2\x20\xe3\x65\xc2\xe3\x7a\xce\xc9\x5a\x6e\x86\x78\x41\x9b\x67\xd5\xe8\xef\x69\x0e\xf0\x88\xc0\x2a\xb2\x70\x0e\xa1\xca\x6a\xbf\x50\x8e\xf6\x40\x59\xef\x8f\xb4\x16\xc6\xec\xe0\xa9\x09\x8e\xfd\x5c\x58\x61\x04\x20\x19\x13\x4c\x31\x87\xd4\x48\x1b\xcd\x3c\xa5\x07\x3f\xc9\x76\x62\x01\xd4\xe0\x0e\x20\xc9\xde\xf7\x0a\xdd\xed\x10\x33\x2a\x31\x83\xb2\x8c\xb0\x20\xd8\xac\xc5\x9b\xd4\xc8\xdf\xc0\x51\x00\x6a\xfe\x77\x31\x3a\xc0\xd0\x7d\xdd\x62\xb7\x97\x11\xb8\x32\x98\x3e\x01\x93\x4a\x9e\xf7\xe0\xa1\x42\x5c\x52\xcb\xb8\xbc\x5a\x04\x7c\xf4\xf0\x9f\x26\xf1\x02\x99\x03\x19\x0b\xb4\x2f\x87\x50\x7a\xa3\x6c\xc8\xde\xd5\x78\x34\xc3\xb1\x1a\x2c\xc7\xd0\xcb\x8b\x14\xe9\xe5\xf4\x54\x94\x21\xe0\xec\x81\x30\x1a\x95\xea\x2d\x1f\xe4\x4d\xdc\x21\x1b\xc6\x55\xd8\xe5\x24\xb2\xf9\xe8\x47\x89\x53\x6f\x72\x2c\xf9\x70\x71\x3e\xb9\xf3\x73\x9b\xbd\x0b\x02\xf8\x90\xe4\x3d\x94\x59\xfa\x09\xfd\x18\x0a\xc7\x8b\x4b\x0b\x00\x85\x34\x40\x5e\x2d\xe1\xb6\xad\xae\x35\xc4\xbe\x49\xd2\xbf\x4e\x9c\x45\xf6\x4d\x46\x64\x1c\x87\xb5\x13\xaf\x2d\x5d\x43\x5f\x07\x2f\x3b\x42\xbc\x45\xbe\xe6\x25\x01\xd3\xec\xbc\x22\xe7\x5c\x4b\x7b\x06\xcb\xc9\x8f\xa6\x66\x36\x1e\x63\x6c\xf5\x0d\xf7\x01\x2f\xae\x84\x74\xcd\x60\x31\x1d\x01\x38\x8e\x2d\x0e\x65\x2c\x32\xa9\x11\xd9\x26\xe2\x74\x34\xf6\x35\x69\x34\xc9\x44\x6c\x95\x68\x09\xbc\xbe\x1f\xe8\xf3\xef\x32\x73\x02\xd5\x56\x82\x3c\x2c\x27\xb7\x7b\x52\x50\x1c\xfb\x43\x0a\xba\x7b\xcf\x1d\xb3\x98\x7f\x25\xc7', 2)

# cleanup
del pyarmor_runtime

